==> cost-interface-0.3.6-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/WelldoneRewardPayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.WelldoneRewardRegistVo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Date;

/**
 * 
 * WelldoneRewardPayDto
 * 数据库表：welldone_reward_pay
 */
public class WelldoneRewardPayVo implements Serializable {

    /**
     * 登记单Vo
     */
    private WelldoneRewardRegistVo registVo;

    /**
     * 
     * 表字段 : welldone_reward_pay.id
     */
    private Integer id;

    /**
     * 核报单号
     * 表字段 : welldone_reward_pay.pay_no
     */
    private String payNo;

    /**
     * 行号
     * 表字段 : welldone_reward_apply.item_no
     */
    private String itemNo;

    /**
     * 登记单号
     * 表字段 : welldone_reward_pay.regist_no
     */
    private String registNo;

    /**
     * 登记单id
     */
    private Integer registId;

    /**
     * 登记单行项目号
     * 表字段 : welldone_reward_pay.regist_item_no
     */
    private String registItemNo;

    /**
     * 申请单号
     * 表字段 : welldone_reward_pay.apply_no
     */
    private String applyNo;

    /**
     * 费用类型编码
     * 表字段 : welldone_reward_pay.cost_type_id
     */
    private String costTypeId;

    /**
     * 费用类型名称
     * 表字段 : welldone_reward_pay.cost_type_name
     */
    private String costTypeName;

    /**
     * 终端编码
     * 表字段 : welldone_reward_pay.terminal_id
     */
    private String terminalId;

    /**
     * 终端名称
     * 表字段 : welldone_reward_pay.terminal_name
     */
    private String terminalName;

    /**
     * 产品编码
     * 表字段 : welldone_reward_pay.product_id
     */
    private String productId;

    /**
     * 产品名称
     * 表字段 : welldone_reward_pay.product_name
     */
    private String productName;

    /**
     * 包量数量(瓶)
     * 表字段 : welldone_reward_pay.buy_num
     */
    private Integer buyNum;

    /**
     * 单瓶包量（元）
     * 表字段 : welldone_reward_pay.dp_limit_quantity
     */
    private BigDecimal dpLimitQuantity;

    /**
     * 单瓶投入(分)
     * 表字段 : welldone_reward_pay.product_price
     */
    private BigDecimal productPrice;

    /**
     * 结算价投入(分)
     * 表字段 : welldone_reward_pay.settlement_price
     */
    private BigDecimal settlementPrice;

    /**
     * 包量金额(分)
     * 表字段 : welldone_reward_pay.total_amount
     */
    private BigDecimal totalAmount;

    /**
     * 厂方承担比例
     * 表字段 : welldone_reward_pay.company_scale
     */
    private Double companyScale;

    /**
     * 厂方承担金额
     * 表字段 : welldone_reward_pay.company_amount
     */
    private BigDecimal companyAmount;

    /**
     * 核报金额(分)
     * 表字段 : welldone_reward_pay.pay_amount
     */
    private BigDecimal payAmount;

    /**
     * 行项目余额(分)
     * 表字段 : welldone_reward_regist.item_balance
     */
    private BigDecimal itemBalance;

    /**
     * 督查意见
     * 表字段 : welldone_reward_pay.audit_notes
     */
    private String auditNotes;

    /**
     * 
     * 表字段 : welldone_reward_pay.create_id
     */
    private String createId;

    /**
     * 
     * 表字段 : welldone_reward_pay.create_name
     */
    private String createName;

    /**
     * 
     * 表字段 : welldone_reward_pay.create_date
     */
    private Date createDate;

    /**
     * 
     * 表字段 : welldone_reward_pay.modify_id
     */
    private String modifyId;

    /**
     * 
     * 表字段 : welldone_reward_pay.modify_name
     */
    private String modifyName;

    /**
     * 
     * 表字段 : welldone_reward_pay.modify_date
     */
    private Date modifyDate;

    /**
     * This field was generated by MyBatis Generator.
     * This field corresponds to the database table welldone_reward_pay
     *
     * @mbggenerated Fri May 12 15:46:42 CST 2017
     */
    private static final long serialVersionUID = 1L;

    /**
     *
     * 表字段 : welldone_reward_pay.id
     */
    public Integer getId() {
        return this.id;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.id
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * 核报单号
     * 表字段 : welldone_reward_pay.pay_no
     */
    public String getPayNo() {
        return this.payNo;
    }

    /**
     * 核报单号
     * 表字段 : welldone_reward_pay.pay_no
     */
    public void setPayNo(String payNo) {
        this.payNo = payNo;
    }

    /**
     * 行号
     * 表字段 : welldone_reward_apply.item_no
     */
    public String getItemNo() {
        return this.itemNo;
    }

    /**
     * 行号
     * 表字段 : welldone_reward_apply.item_no
     */
    public void setItemNo(String itemNo) {
        this.itemNo = itemNo;
    }

    /**
     * 登记单号
     * 表字段 : welldone_reward_pay.regist_no
     */
    public String getRegistNo() {
        return this.registNo;
    }

    /**
     * 登记单号
     * 表字段 : welldone_reward_pay.regist_no
     */
    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    /**
     * 登记单行项目号
     * 表字段 : welldone_reward_pay.regist_item_no
     */
    public String getRegistItemNo() {
        return this.registItemNo;
    }

    /**
     * 登记单行项目号
     * 表字段 : welldone_reward_pay.regist_item_no
     */
    public void setRegistItemNo(String registItemNo) {
        this.registItemNo = registItemNo;
    }

    /**
     * 申请单号
     * 表字段 : welldone_reward_pay.apply_no
     */
    public String getApplyNo() {
        return this.applyNo;
    }

    /**
     * 申请单号
     * 表字段 : welldone_reward_pay.apply_no
     */
    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    /**
     * 终端编码
     * 表字段 : welldone_reward_pay.terminal_id
     */
    public String getTerminalId() {
        return this.terminalId;
    }

    /**
     * 终端编码
     * 表字段 : welldone_reward_pay.terminal_id
     */
    public void setTerminalId(String terminalId) {
        this.terminalId = terminalId;
    }

    /**
     * 终端名称
     * 表字段 : welldone_reward_pay.terminal_name
     */
    public String getTerminalName() {
        return this.terminalName;
    }

    /**
     * 终端名称
     * 表字段 : welldone_reward_pay.terminal_name
     */
    public void setTerminalName(String terminalName) {
        this.terminalName = terminalName;
    }

    /**
     * 产品编码
     * 表字段 : welldone_reward_pay.product_id
     */
    public String getProductId() {
        return this.productId;
    }

    /**
     * 产品编码
     * 表字段 : welldone_reward_pay.product_id
     */
    public void setProductId(String productId) {
        this.productId = productId;
    }

    /**
     * 产品名称
     * 表字段 : welldone_reward_pay.product_name
     */
    public String getProductName() {
        return this.productName;
    }

    /**
     * 产品名称
     * 表字段 : welldone_reward_pay.product_name
     */
    public void setProductName(String productName) {
        this.productName = productName;
    }

    /**
     * 包量数量(瓶)
     * 表字段 : welldone_reward_pay.buy_num
     */
    public Integer getBuyNum() {
        return this.buyNum;
    }

    /**
     * 包量数量(瓶)
     * 表字段 : welldone_reward_pay.buy_num
     */
    public void setBuyNum(Integer buyNum) {
        this.buyNum = buyNum;
    }

    /**
     * 单瓶包量（元）
     * 表字段 : welldone_reward_pay.dp_limit_quantity
     */
    public BigDecimal getDpLimitQuantity() {
        return this.dpLimitQuantity;
    }

    /**
     * 单瓶包量（元）
     * 表字段 : welldone_reward_pay.dp_limit_quantity
     */
    public void setDpLimitQuantity(BigDecimal dpLimitQuantity) {
        this.dpLimitQuantity = dpLimitQuantity;
    }

    /**
     * 单瓶投入(分)
     * 表字段 : welldone_reward_pay.product_price
     */
    public BigDecimal getProductPrice() {
        if( this.productPrice != null) {
            return (this.productPrice.divide(new BigDecimal(100),2, RoundingMode.HALF_UP));
        }
        return this.productPrice;
    }

    /**
     * 单瓶投入(分)
     * 表字段 : welldone_reward_pay.product_price
     */
    public void setProductPrice(BigDecimal productPrice) {
        this.productPrice = productPrice;
    }

    /**
     * 结算价投入(分)
     * 表字段 : welldone_reward_pay.settlement_price
     */
    public BigDecimal getSettlementPrice() {
        return this.settlementPrice;
    }

    /**
     * 结算价投入(分)
     * 表字段 : welldone_reward_pay.settlement_price
     */
    public void setSettlementPrice(BigDecimal settlementPrice) {
        this.settlementPrice = settlementPrice;
    }

    /**
     * 包量金额(分)
     * 表字段 : welldone_reward_pay.total_amount
     */
    public BigDecimal getTotalAmount() {
        if( this.totalAmount != null) {
            return (this.totalAmount.divide(new BigDecimal(100),2, RoundingMode.HALF_UP));
        }
        return this.totalAmount;
    }

    /**
     * 包量金额(分)
     * 表字段 : welldone_reward_pay.total_amount
     */
    public void setTotalAmount(BigDecimal totalAmount) {
        this.totalAmount = totalAmount;
    }

    /**
     * 厂方承担比例
     * 表字段 : welldone_reward_pay.company_scale
     */
    public Double getCompanyScale() {
        return this.companyScale;
    }

    /**
     * 厂方承担比例
     * 表字段 : welldone_reward_pay.company_scale
     */
    public void setCompanyScale(Double companyScale) {
        this.companyScale = companyScale;
    }

    /**
     * 厂方承担金额
     * 表字段 : welldone_reward_pay.company_amount
     */
    public BigDecimal getCompanyAmount() {
        return this.companyAmount;
    }

    /**
     * 厂方承担金额
     * 表字段 : welldone_reward_pay.company_amount
     */
    public void setCompanyAmount(BigDecimal companyAmount) {
        this.companyAmount = companyAmount;
    }

    /**
     * 核报金额(分)
     * 表字段 : welldone_reward_pay.pay_amount
     */
    public BigDecimal getPayAmount() {
        if( this.payAmount != null) {
            return (this.payAmount.divide(new BigDecimal(100),2, RoundingMode.HALF_UP));
        }
        return this.payAmount;
    }

    /**
     * 核报金额(分)
     * 表字段 : welldone_reward_pay.pay_amount
     */
    public void setPayAmount(BigDecimal payAmount) {
        this.payAmount = payAmount;
    }

    /**
     * 督查意见
     * 表字段 : welldone_reward_pay.audit_notes
     */
    public String getAuditNotes() {
        return this.auditNotes;
    }

    /**
     * 督查意见
     * 表字段 : welldone_reward_pay.audit_notes
     */
    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.create_id
     */
    public String getCreateId() {
        return this.createId;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.create_id
     */
    public void setCreateId(String createId) {
        this.createId = createId;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.create_name
     */
    public String getCreateName() {
        return this.createName;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.create_name
     */
    public void setCreateName(String createName) {
        this.createName = createName;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.create_date
     */
    public Date getCreateDate() {
        return this.createDate;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.create_date
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.modify_id
     */
    public String getModifyId() {
        return this.modifyId;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.modify_id
     */
    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.modify_name
     */
    public String getModifyName() {
        return this.modifyName;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.modify_name
     */
    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.modify_date
     */
    public Date getModifyDate() {
        return this.modifyDate;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.modify_date
     */
    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }

    /**
     * 行项目余额(分)
     * 表字段 : welldone_reward_regist.item_balance
     */
    public BigDecimal getItemBalance() {
        return this.itemBalance;
    }

    /**
     * 行项目余额(分)
     * 表字段 : welldone_reward_regist.item_balance
     */
    public void setItemBalance(BigDecimal itemBalance) {
        this.itemBalance = itemBalance;
    }

    /**
     * 获取 登记单id
     */
    public Integer getRegistId() {
        return this.registId;
    }

    /**
     * 设置 登记单id
     */
    public void setRegistId(Integer registId) {
        this.registId = registId;
    }

    /**
     * 获取 登记单Vo
     */
    public WelldoneRewardRegistVo getRegistVo() {
        return this.registVo;
    }

    /**
     * 设置 登记单Vo
     */
    public void setRegistVo(WelldoneRewardRegistVo registVo) {
        this.registVo = registVo;
    }

    /**
     * 费用类型编码
     * 表字段 : welldone_reward_pay.cost_type_id
     */
    public String getCostTypeId() {
        return this.costTypeId;
    }

    /**
     * 费用类型编码
     * 表字段 : welldone_reward_pay.cost_type_id
     */
    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    /**
     * 费用类型名称
     * 表字段 : welldone_reward_pay.cost_type_name
     */
    public String getCostTypeName() {
        return this.costTypeName;
    }

    /**
     * 费用类型名称
     * 表字段 : welldone_reward_pay.cost_type_name
     */
    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }
}

==> cost-interface-0.3.13-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/WelldoneRewardPayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.WelldoneRewardRegistVo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Date;

/**
 * 
 * WelldoneRewardPayDto
 * 数据库表：welldone_reward_pay
 */
public class WelldoneRewardPayVo implements Serializable {

    /**
     * 登记单Vo
     */
    private WelldoneRewardRegistVo registVo;

    /**
     * 
     * 表字段 : welldone_reward_pay.id
     */
    private Integer id;

    /**
     * 核报单号
     * 表字段 : welldone_reward_pay.pay_no
     */
    private String payNo;

    /**
     * 行号
     * 表字段 : welldone_reward_apply.item_no
     */
    private Integer itemNo;

    /**
     * 登记单号
     * 表字段 : welldone_reward_pay.regist_no
     */
    private String registNo;

    /**
     * 登记单id
     */
    private Integer registId;

    /**
     * 登记单行项目号
     * 表字段 : welldone_reward_pay.regist_item_no
     */
    private String registItemNo;

    /**
     * 申请单号
     * 表字段 : welldone_reward_pay.apply_no
     */
    private String applyNo;

    /**
     * 费用类型编码
     * 表字段 : welldone_reward_pay.cost_type_id
     */
    private String costTypeId;

    /**
     * 费用类型名称
     * 表字段 : welldone_reward_pay.cost_type_name
     */
    private String costTypeName;

    /**
     * 终端编码
     * 表字段 : welldone_reward_pay.terminal_id
     */
    private String terminalId;

    /**
     * 终端名称
     * 表字段 : welldone_reward_pay.terminal_name
     */
    private String terminalName;

    /**
     * 产品编码
     * 表字段 : welldone_reward_pay.product_id
     */
    private String productId;

    /**
     * 产品名称
     * 表字段 : welldone_reward_pay.product_name
     */
    private String productName;

    /**
     * 包量数量(瓶)
     * 表字段 : welldone_reward_pay.buy_num
     */
    private Integer buyNum;

    /**
     * 单瓶包量（元）
     * 表字段 : welldone_reward_pay.dp_limit_quantity
     */
    private BigDecimal dpLimitQuantity;

    /**
     * 单瓶投入(分)
     * 表字段 : welldone_reward_pay.product_price
     */
    private BigDecimal productPrice;

    /**
     * 结算价投入(分)
     * 表字段 : welldone_reward_pay.settlement_price
     */
    private BigDecimal settlementPrice;

    /**
     * 包量金额(分)
     * 表字段 : welldone_reward_pay.total_amount
     */
    private BigDecimal totalAmount;

    /**
     * 厂方承担比例
     * 表字段 : welldone_reward_pay.company_scale
     */
    private Double companyScale;

    /**
     * 厂方承担金额
     * 表字段 : welldone_reward_pay.company_amount
     */
    private BigDecimal companyAmount;

    /**
     * 核报金额(分)
     * 表字段 : welldone_reward_pay.pay_amount
     */
    private BigDecimal payAmount;

    /**
     * 行项目余额(分)
     * 表字段 : welldone_reward_regist.item_balance
     */
    private BigDecimal itemBalance;

    /**
     * 督查意见
     * 表字段 : welldone_reward_pay.audit_notes
     */
    private String auditNotes;

    /**
     * 
     * 表字段 : welldone_reward_pay.create_id
     */
    private String createId;

    /**
     * 
     * 表字段 : welldone_reward_pay.create_name
     */
    private String createName;

    /**
     * 
     * 表字段 : welldone_reward_pay.create_date
     */
    private Date createDate;

    /**
     * 
     * 表字段 : welldone_reward_pay.modify_id
     */
    private String modifyId;

    /**
     * 
     * 表字段 : welldone_reward_pay.modify_name
     */
    private String modifyName;

    /**
     * 
     * 表字段 : welldone_reward_pay.modify_date
     */
    private Date modifyDate;

    /**
     * This field was generated by MyBatis Generator.
     * This field corresponds to the database table welldone_reward_pay
     *
     * @mbggenerated Fri May 12 15:46:42 CST 2017
     */
    private static final long serialVersionUID = 1L;

    /**
     *
     * 表字段 : welldone_reward_pay.id
     */
    public Integer getId() {
        return this.id;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.id
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * 核报单号
     * 表字段 : welldone_reward_pay.pay_no
     */
    public String getPayNo() {
        return this.payNo;
    }

    /**
     * 核报单号
     * 表字段 : welldone_reward_pay.pay_no
     */
    public void setPayNo(String payNo) {
        this.payNo = payNo;
    }

    /**
     * 行号
     * 表字段 : welldone_reward_apply.item_no
     */
    public Integer getItemNo() {
        return this.itemNo;
    }

    /**
     * 行号
     * 表字段 : welldone_reward_apply.item_no
     */
    public void setItemNo(Integer itemNo) {
        this.itemNo = itemNo;
    }

    /**
     * 登记单号
     * 表字段 : welldone_reward_pay.regist_no
     */
    public String getRegistNo() {
        return this.registNo;
    }

    /**
     * 登记单号
     * 表字段 : welldone_reward_pay.regist_no
     */
    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    /**
     * 登记单行项目号
     * 表字段 : welldone_reward_pay.regist_item_no
     */
    public String getRegistItemNo() {
        return this.registItemNo;
    }

    /**
     * 登记单行项目号
     * 表字段 : welldone_reward_pay.regist_item_no
     */
    public void setRegistItemNo(String registItemNo) {
        this.registItemNo = registItemNo;
    }

    /**
     * 申请单号
     * 表字段 : welldone_reward_pay.apply_no
     */
    public String getApplyNo() {
        return this.applyNo;
    }

    /**
     * 申请单号
     * 表字段 : welldone_reward_pay.apply_no
     */
    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    /**
     * 终端编码
     * 表字段 : welldone_reward_pay.terminal_id
     */
    public String getTerminalId() {
        return this.terminalId;
    }

    /**
     * 终端编码
     * 表字段 : welldone_reward_pay.terminal_id
     */
    public void setTerminalId(String terminalId) {
        this.terminalId = terminalId;
    }

    /**
     * 终端名称
     * 表字段 : welldone_reward_pay.terminal_name
     */
    public String getTerminalName() {
        return this.terminalName;
    }

    /**
     * 终端名称
     * 表字段 : welldone_reward_pay.terminal_name
     */
    public void setTerminalName(String terminalName) {
        this.terminalName = terminalName;
    }

    /**
     * 产品编码
     * 表字段 : welldone_reward_pay.product_id
     */
    public String getProductId() {
        return this.productId;
    }

    /**
     * 产品编码
     * 表字段 : welldone_reward_pay.product_id
     */
    public void setProductId(String productId) {
        this.productId = productId;
    }

    /**
     * 产品名称
     * 表字段 : welldone_reward_pay.product_name
     */
    public String getProductName() {
        return this.productName;
    }

    /**
     * 产品名称
     * 表字段 : welldone_reward_pay.product_name
     */
    public void setProductName(String productName) {
        this.productName = productName;
    }

    /**
     * 包量数量(瓶)
     * 表字段 : welldone_reward_pay.buy_num
     */
    public Integer getBuyNum() {
        return this.buyNum;
    }

    /**
     * 包量数量(瓶)
     * 表字段 : welldone_reward_pay.buy_num
     */
    public void setBuyNum(Integer buyNum) {
        this.buyNum = buyNum;
    }

    /**
     * 单瓶包量（元）
     * 表字段 : welldone_reward_pay.dp_limit_quantity
     */
    public BigDecimal getDpLimitQuantity() {
        return this.dpLimitQuantity;
    }

    /**
     * 单瓶包量（元）
     * 表字段 : welldone_reward_pay.dp_limit_quantity
     */
    public void setDpLimitQuantity(BigDecimal dpLimitQuantity) {
        this.dpLimitQuantity = dpLimitQuantity;
    }

    /**
     * 单瓶投入(分)
     * 表字段 : welldone_reward_pay.product_price
     */
    public BigDecimal getProductPrice() {
        if( this.productPrice != null) {
            return (this.productPrice.divide(new BigDecimal(100),2, RoundingMode.HALF_UP));
        }
        return this.productPrice;
    }

    /**
     * 单瓶投入(分)
     * 表字段 : welldone_reward_pay.product_price
     */
    public void setProductPrice(BigDecimal productPrice) {
        this.productPrice = productPrice;
    }

    /**
     * 结算价投入(分)
     * 表字段 : welldone_reward_pay.settlement_price
     */
    public BigDecimal getSettlementPrice() {
        return this.settlementPrice;
    }

    /**
     * 结算价投入(分)
     * 表字段 : welldone_reward_pay.settlement_price
     */
    public void setSettlementPrice(BigDecimal settlementPrice) {
        this.settlementPrice = settlementPrice;
    }

    /**
     * 包量金额(分)
     * 表字段 : welldone_reward_pay.total_amount
     */
    public BigDecimal getTotalAmount() {
        if( this.totalAmount != null) {
            return (this.totalAmount.divide(new BigDecimal(100),2, RoundingMode.HALF_UP));
        }
        return this.totalAmount;
    }

    /**
     * 包量金额(分)
     * 表字段 : welldone_reward_pay.total_amount
     */
    public void setTotalAmount(BigDecimal totalAmount) {
        this.totalAmount = totalAmount;
    }

    /**
     * 厂方承担比例
     * 表字段 : welldone_reward_pay.company_scale
     */
    public Double getCompanyScale() {
        return this.companyScale;
    }

    /**
     * 厂方承担比例
     * 表字段 : welldone_reward_pay.company_scale
     */
    public void setCompanyScale(Double companyScale) {
        this.companyScale = companyScale;
    }

    /**
     * 厂方承担金额
     * 表字段 : welldone_reward_pay.company_amount
     */
    public BigDecimal getCompanyAmount() {
        return this.companyAmount;
    }

    /**
     * 厂方承担金额
     * 表字段 : welldone_reward_pay.company_amount
     */
    public void setCompanyAmount(BigDecimal companyAmount) {
        this.companyAmount = companyAmount;
    }

    /**
     * 核报金额(分)
     * 表字段 : welldone_reward_pay.pay_amount
     */
    public BigDecimal getPayAmount() {
        if( this.payAmount != null) {
            return (this.payAmount.divide(new BigDecimal(100),2, RoundingMode.HALF_UP));
        }
        return this.payAmount;
    }

    /**
     * 核报金额(分)
     * 表字段 : welldone_reward_pay.pay_amount
     */
    public void setPayAmount(BigDecimal payAmount) {
        this.payAmount = payAmount;
    }

    /**
     * 督查意见
     * 表字段 : welldone_reward_pay.audit_notes
     */
    public String getAuditNotes() {
        return this.auditNotes;
    }

    /**
     * 督查意见
     * 表字段 : welldone_reward_pay.audit_notes
     */
    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.create_id
     */
    public String getCreateId() {
        return this.createId;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.create_id
     */
    public void setCreateId(String createId) {
        this.createId = createId;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.create_name
     */
    public String getCreateName() {
        return this.createName;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.create_name
     */
    public void setCreateName(String createName) {
        this.createName = createName;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.create_date
     */
    public Date getCreateDate() {
        return this.createDate;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.create_date
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.modify_id
     */
    public String getModifyId() {
        return this.modifyId;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.modify_id
     */
    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.modify_name
     */
    public String getModifyName() {
        return this.modifyName;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.modify_name
     */
    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.modify_date
     */
    public Date getModifyDate() {
        return this.modifyDate;
    }

    /**
     *
     * 表字段 : welldone_reward_pay.modify_date
     */
    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }

    /**
     * 行项目余额(分)
     * 表字段 : welldone_reward_regist.item_balance
     */
    public BigDecimal getItemBalance() {
        return this.itemBalance;
    }

    /**
     * 行项目余额(分)
     * 表字段 : welldone_reward_regist.item_balance
     */
    public void setItemBalance(BigDecimal itemBalance) {
        this.itemBalance = itemBalance;
    }

    /**
     * 获取 登记单id
     */
    public Integer getRegistId() {
        return this.registId;
    }

    /**
     * 设置 登记单id
     */
    public void setRegistId(Integer registId) {
        this.registId = registId;
    }

    /**
     * 获取 登记单Vo
     */
    public WelldoneRewardRegistVo getRegistVo() {
        return this.registVo;
    }

    /**
     * 设置 登记单Vo
     */
    public void setRegistVo(WelldoneRewardRegistVo registVo) {
        this.registVo = registVo;
    }

    /**
     * 费用类型编码
     * 表字段 : welldone_reward_pay.cost_type_id
     */
    public String getCostTypeId() {
        return this.costTypeId;
    }

    /**
     * 费用类型编码
     * 表字段 : welldone_reward_pay.cost_type_id
     */
    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    /**
     * 费用类型名称
     * 表字段 : welldone_reward_pay.cost_type_name
     */
    public String getCostTypeName() {
        return this.costTypeName;
    }

    /**
     * 费用类型名称
     * 表字段 : welldone_reward_pay.cost_type_name
     */
    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }
}
